from setuptools import setup

setup(
    name='pycrescolib',
    version='0.12',
    packages=['pycrescolib'],
    url='http://cresco.io',
    license='Apache 2.0',
    author='Cresco Team',
    author_email='info@cresco.io',
    description='Python Cresco Client Library',
    install_requires=['websocket-client'],

)
